```
  _____  _____  _     _ ______ _______    ______ _
 / ____|/ ___ \| |   | |  __  \__   __|  |  __  (_)
| |    | |   | | |   | | |__| |  | |     | |__| |_ ____    ___ _ __
| |    | |  _| | |   | |  ____/  | |     |  ____/ |  __ \ / _ \ '__\
| |___ | |__\  | |___| | |       | |     | |    | | |__| |  __/ |
 \____/ \____/\_\_____/|_|       |_|     |_|    |_|  ___/ \___|_|
                                                  |_|
```

![](https://img.shields.io/badge/build-passing-brightgreen) ![](https://img.shields.io/badge/license-MIT-blue) ![](https://img.shields.io/badge/Python-3%2B-yellowgreen)


## Documentation

Documentation is at [https://cquptpiper.xjj.pub](https://cquptpiper.xjj.pub)

## Contribution

You can help create better `crawler` under directory [crawler](https://github.com/mivinci/cqupt-piper/tree/master/cqupt/crawlers). 

Fork this repo and commit your request!

## Todo

- [ ] **GUI** Expected in version 2+

## License

© XJJ, 2019~datetime.now()

Released under the [MIT License](https://github.com/mivinci/cqupt-piper/blob/master/LICENSE)